pub struct ContextID(/* private fields */);Expand description
A unique identifier, used to identify cached context data within a given
interpreter. For more information see the discussion of command definition
and the context cache in The Molt Book and the interp module.