MoltInt

Type Alias MoltInt 

pub type MoltInt = i64;
The standard integer type for Molt code.

The interpreter uses this type internally for all Molt integer values. The primary reason for defining this as a type alias is future-proofing: at some point we may wish to replace MoltInt with a more powerful type that supports BigNums, or switch to i128.