pub struct Subcommand(pub &'static str, pub CommandFunc);Expand description
A Molt command that has subcommands is called an ensemble command. In Rust code,
the ensemble is defined as an array of Subcommand structs, each one mapping from
a subcommand name to the implementing CommandFunc. For more information,
see the discussion of command definition in The Molt Book and the interp module.
The tuple fields are the subcommand’s name and implementing CommandFunc.
Tuple Fields
0: &'static str1: CommandFuncImplementations
Sourceimpl Subcommand
impl Subcommand
Sourcepub fn find<'a>(
ensemble: &'a [Subcommand],
sub_name: &str,
) -> Result<&'a Subcommand, Exception>
pub fn find<'a>( ensemble: &'a [Subcommand], sub_name: &str, ) -> Result<&'a Subcommand, Exception>
Looks up a subcommand of an ensemble command by name in a table,
returning the usual error if it can’t be found. It is up to the
ensemble command to call the returned subcommand with the
appropriate arguments. See the implementation of the info
command for an example.
TCL Notes
- In standard TCL, subcommand lookups accept any unambiguous prefix of the subcommand name, as a convenience for interactive use. Molt does not, as it is confusing when used in scripts.